
close all
clear
clc

%Anti surge controller compressor C2
comcharC2
%Standard cubic meter
M =28.97                  %molar mass [g/mol]
Pscm=1.01325*10^5;       %Standar Pressure [Psi] 
R=8.314472;              %ideal gas constant [J/(mol*K)]
Tscm=15+273.15;          %absolute temperature [K]
rhos=Pscm*M/(R*Tscm*10^3);%density [kg/m^3]

%Surge avoidance line old controller
M=[0:1:75];
P1=34.25
D1=3600/(1000*rhos);
C1=0.556495; %A1Cy1
C2=0.02949+1.3;  %B1
C3=1*D1/P1;    %CxD1
E = 0;
DSP = 0;
Prsa=-C2/C1+(E-DSP)/C1+(C3*M)/(C1);

%Surge avoidance line new controller
Ti=29.8+273.15;  %Inlet temprature [k]
MW=22.831;       %Molecular weight 
pi=34.25*10^5;    %Inlet pressure [Pa]
Sflow=0.3e5;                                                         %Scale the flow coefficient 
exs=[1.4800    2.5704   3.6917];                                     %Exponents of Nc
ca= [-2.9532   12.3330  -17.5687   13.3420  5.4        1.94     6 ]; %Pressure coefficient

Flowc=1.49
Nc=[0.7:0.01:1.2]
for i=1:size(Nc,2)
    
    if ca(6)>Flowc
        Pressc=ca(1)*Flowc^3+ca(2)*Flowc^2+ca(3)*Flowc+ca(4);
    else
        Pressc=ca(1)*Flowc^3+ca(2)*Flowc^2+ca(3)*Flowc+ca(4)-(ca(5)*(Flowc-ca(6)))^ca(7);
    end
    Prsa2(i)=Pressc*Nc(i)^exs(2);
    MPrsa2(i)=Flowc*pi*(MW)^0.5*Nc(i)^exs(1)/(Sflow*(Ti)^0.5);
end




figure(2)
subplot(1,2,1)
hold on
plot(MPrC209,RaC209,'b','LineWidth',2);
plot(MPrC2095,RaC2095,'b','LineWidth',2);
plot(MPrC21,RaC21,'b','LineWidth',2);
plot(MPrC2105,RaC2105,'b','LineWidth',2);
plot(MPrs,Ras,'r','LineWidth',2);
plot(M,Prsa,'k','LineWidth',2);
plot(MPrsa2,Prsa2,'g','LineWidth',2);



axis([30 75 1 6.5])
grid
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')
title('Compressor C2')


%Anti surge controller compressor C3
comcharC3
%Standard cubic meter
M =28.97                  %molar mass [g/mol]
Pscm=1.01325*10^5;        %Standar Pressure [Psi] 
R=8.314472;               %ideal gas constant [J/(mol*K)]
Tscm=15+273.15;           %absolute temperature [K]
rhos=Pscm*M/(R*Tscm*10^3);%density [kg/m^3]

%Surge avoidance line old controller
M=[0:1:75];
P1=10.7
D1=3600/(1000*rhos);
C1=0.6013;      %A1Cy1
C2=-0.1668;     %B1
C3=1*D1/P1;     %CxD1
E = 0;
DSP = 0;
Prsa=-C2/C1+(E-DSP)/C1+(C3*M)/(C1);

%Surge avoidance line new controller
Ti=29.7+273.15;  %Inlet temprature [k]
MW=29.136;       %Molecular weight 
pi=10.8*10^5;    %Inlet pressure [Pa]
Sflow=0.3e5;                                                         %Scale the flow coefficient 
exs=[1.3168    2.7378    3.6754];                                    %Exponents of Nc
ca= [-40.6294   78.3467  -51.5891   15.7665  9.05        0.82    6]; %Pressure coefficient

Flowc=0.72;
Nc=[0.7:0.01:1.2]
for i=1:size(Nc,2)
    if ca(6)>Flowc
        Pressc=ca(1)*Flowc^3+ca(2)*Flowc^2+ca(3)*Flowc+ca(4);
    else
        Pressc=ca(1)*Flowc^3+ca(2)*Flowc^2+ca(3)*Flowc+ca(4)-(ca(5)*(Flowc-ca(6)))^ca(7);
    end
    Prsa2(i)=Pressc*Nc(i)^exs(2);
    MPrsa2(i)=Flowc*pi*(MW)^0.5*Nc(i)^exs(1)/(Sflow*(Ti)^0.5);
end


figure(2)
subplot(1,2,2)
hold on
plot(MPrC309,RaC309,'b','LineWidth',2);
plot(MPrC3095,RaC3095,'b','LineWidth',2);
plot(MPrC31,RaC31,'b','LineWidth',2);
plot(MPrC3105,RaC3105,'b','LineWidth',2);
plot(MPrs,Ras,'r','LineWidth',2);
plot(M,Prsa,'k','LineWidth',2);
plot(MPrsa2,Prsa2,'g','LineWidth',2);



axis([5 12 1.5 5])
grid
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')
title('Compressor C3')
