% Compressor characteristic compressor 3.  
clear 
close all
clc


%Discharge pressure curves
VPrC425=[465    474,     478,     480]*10;        %Volum flow [m3/h] 
PrC425=[10.3    8        7        5 ]*10^5;       %Outlet pressure [Psi] 

VPrC435=[580    603     610     609]*10;
PrC435=[12.9    9       7       5.8]*10^5;       

VPrC443=[720    750     758     759]*10;
PrC443=[15.4    11      8       5.8]*10^5;   

VPrC465=[828    865    880     919     933     935]*10;
PrC465=[17.4    16.6   16      13      9       6.4]*10^5;       

VPrC4105=[890   920    960     1000    1040     1060   1080    1085]*10;
PrC4105=[19     18.8   18.3    17.3     15.4    13.8   10.5    7.3]*10^5;         


%Surge line 
VPrs=[465   580     720     828     890]*10;
Prs=[10.3   12.9    15.4    17.4    19]*10^5;

%Power at comprssor coupling curves 
VPoC425=[465    480]*10;
PoC425= [70     65]*10^4; 

VPoC435=[580    609]*10;
PoC435= [92     78]*10^4; 

VPoC443=[720    745     753     759]*10;
PoC443= [112    109     105     98]*10^4; 

VPoC465=[828    880     915     935]*10;
PoC465= [130    130     126     120]*10^4; 

VPoC4105=[890   980   1000    1040    1060    1085]*10;
PoC4105=[144    151   152     152     150     143]*10^4;


%Density to the inlet gas 
M = 42.756;                     %Molar mass [g/mol]
Z=1;                            %Compressibility factor
Pin=1.3*10^5;                  %Inlet Pressure [Psi] 
R=8.314472;                     %Gas constant [J/(mol*K)]
Tin=28.6+273.16;                %Absolute inlet temperature [K]
rho=Pin*M/(Z*R*Tin*10^3);       %Density [kg/m^3]

% %Conversion form [m3/h] to [kg/s]
MPrC425=VPrC425*rho/3600;        %mass flow [Kg/s]
MPrC435=VPrC435*rho/3600;        %mass flow [Kg/s]
MPrC443=VPrC443*rho/3600;        %mass flow [Kg/s]
MPrC465=VPrC465*rho/3600;        %mass flow [Kg/s]
MPrC4105=VPrC4105*rho/3600;      %mass flow [Kg/s]
MPrs=VPrs*rho/3600;              %mass flow [Kg/s]

MPoC425=VPoC425*rho/3600;        %mass flow [Kg/s]
MPoC435=VPoC435*rho/3600;        %mass flow [Kg/s]
MPoC443=VPoC443*rho/3600;        %mass flow [Kg/s]
MPoC465=VPoC465*rho/3600;        %mass flow [Kg/s]
MPoC4105=VPoC4105*rho/3600;      %mass flow [Kg/s]


%Conversion for discharge prssure to pressure ratio 
PASP=1.3*10^5;          %pressure inlet [Psi]
RaC425=PrC425/PASP;      %pressure ratio 
RaC435=PrC435/PASP;      %pressure ratio
RaC443=PrC443/PASP;      %pressure ratio
RaC465=PrC465/PASP;       %pressure ratio 
RaC4105=PrC4105/PASP;      %pressure ratio 
Ras=Prs/PASP;            %pressure ratio 




figure(1)
subplot(2,1,1)
plot(MPrC425,RaC425,'k','LineWidth',2);
hold on
plot(MPrC435,RaC435,'k','LineWidth',2);
hold on
plot(MPrC443,RaC443,'k','LineWidth',2);
hold on
plot(MPrC465,RaC465,'k','LineWidth',2);
hold on
plot(MPrC4105,RaC4105,'k','LineWidth',2);
hold on
plot(MPrs,Ras,'k--','LineWidth',2);
axis([2.5 7 2 16])
grid
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')
text(3,5,'25\circ','FontSize',12,'FontWeight','bold')
text(3.8,5,'35\circ','FontSize',12,'FontWeight','bold')
text(4.8,5,'43\circ','FontSize',12,'FontWeight','bold')
text(5.8,7,'65\circ','FontSize',12,'FontWeight','bold')
text(6.5,13,'105\circ','FontSize',12,'FontWeight','bold')



subplot(2,1,2)
plot(MPoC425,PoC425,'k','LineWidth',2)
hold on
plot(MPoC435,PoC435,'k','LineWidth',2)
hold on
plot(MPoC443,PoC443,'k','LineWidth',2)
hold on
plot(MPoC465,PoC465,'k','LineWidth',2)
hold on
plot(MPoC4105,PoC4105,'k','LineWidth',2)
axis([2.5 7 0.5e6 1.8e6])
grid
xlabel('Mass flow [Kg/s]'), ylabel('Power at compressor coupling [W]')
text(3,0.7e6,'25\circ','FontSize',12,'FontWeight','bold')
text(3.7,0.95e6,'35\circ','FontSize',12,'FontWeight','bold')
text(4.8,1e6,'43\circ','FontSize',12,'FontWeight','bold')
text(5.8,1.2e6,'65\circ','FontSize',12,'FontWeight','bold')
text(6.5,1.35e6,'105\circ','FontSize',12,'FontWeight','bold')

