%Compressor characteristics with dimensionless parameters method for
%Compress C2 and C3
Com=2  %Chose 3 for compressor C3 or 2 for compressor C2;

if Com==3;
comcharC32
%Compressor C2
C.S(1).Com    =[MPrC309;RaC309];
C.S(1).Power  =[MPoC309;PoC309];
C.S(1).Speed  =0.9;

C.S(2).Com    =[MPrC3095;RaC3095;];
C.S(2).Power  =[MPoC3095;PoC3095];
C.S(2).Speed  =0.95;

C.S(3).Com    =[MPrC31;RaC31;];
C.S(3).Power  =[MPoC31;PoC31];
C.S(3).Speed  =1;

C.S(4).Com    =[MPrC3105;RaC3105;];
C.S(4).Power  =[MPoC3105;PoC3105];
C.S(4).Speed  =1.05;

clearvars -regexp ^*$ -except C rho Com
close all

%Constants
Ti=29.7+273.15;  %Inlet temprature [k]
MW=29.136;       %Molecular weight 
pi=10.8*10^5;    %Inlet pressure [Pa]
Sflow=0.3e5;     %Scale the flow coefficient 
C.Constants=[Ti,MW,pi,Sflow];

res=0.01         %Resolution for interpolation  

%Constnats for nonlinear term  pressure coefficient approximation
Ca5=9.05;
Ca6=0.82;
Ca7=6;

Com=3;
end

if Com==2;
    
comcharC2
%Compressor C2
C.S(1).Com    =[MPrC209;RaC209;];
C.S(1).Power  =[MPoC209;PoC209];
C.S(1).Speed  =0.9;

C.S(2).Com    =[MPrC2095;RaC2095;];
C.S(2).Power  =[MPoC2095;PoC2095];
C.S(2).Speed  =0.95;

C.S(3).Com    =[MPrC21;RaC21;];
C.S(3).Power  =[MPoC21;PoC21];
C.S(3).Speed  =1;

C.S(4).Com    =[MPrC2105;RaC2105;];
C.S(4).Power  =[MPoC2105;PoC2105];
C.S(4).Speed  =1.05;

clearvars -regexp ^*$ -except C rho Com
close all

%Constants
Ti=29.8+273.15;  %Inlet temprature [k]
MW=22.831;       %Molecular weight 
pi=34.25*10^5;    %Inlet pressure [Pa]
Sflow=0.3e5;     %Scale the flow coefficient 
C.Constants=[Ti,MW,pi,Sflow];

res=0.1         %Resolution for interpolation  

%Constnats for nonlinear term  pressure coefficient approximation
Ca5=5.4;
Ca6=1.94;
Ca7=6;

end


%Interpolation between points in compressor characteristics 
for i=[1:4]
    minx=min([C.S(i).Power(1,1),C.S(i).Com(1,1)]);
    maxx=max([C.S(i).Power(1,end),C.S(i).Com(1,end)]);
    massflow=[minx:res:maxx];
    Pratio =interp1(C.S(i).Com(1,:),C.S(i).Com(2,:),massflow,'pchip');
    Power  =interp1(C.S(i).Power(1,:),C.S(i).Power(2,:),massflow,'linear');
    C.S(i).Coms=[Pratio;Power;massflow];
end

% Optimization to find exsponents to speed 
%Initial conditions
exs1=1.4; %Speed exsponent in flow coefficient 
exs2=2.4; %Speed exsponent in Pressure coefficient 
exs3=3.6; %Speed exsponent in Power coefficient 
X0=[exs1,exs2,exs3];

%Multidimensional unconstrained nonlinear minimization
[X,FVAL,EXITFLAG,OUTPUT]= fminsearch(@(X) objcch2(X,C),X0)

figure(1)
grid
hold on
xlabel('Flow coefficient'),ylabel('Pressure coeffcient')

figure(2)
grid
hold on
xlabel('Flow coefficient'),ylabel('Power coeffcient')


color=[0.8 0.8 0.8; 0.5 0.5 0.5; 0.31 0.31 0.31;0 0 0];
for i=[1:4]
S(i).flowc=Sflow*C.S(i).Coms(3,:)*Ti^0.5*pi^-1*MW^-.5*C.S(i).Speed^-X(1);    %Flow coefficient
S(i).pressc=C.S(i).Coms(1,:)*C.S(i).Speed^-X(2);                             %Pressure coefficient
S(i).powc=C.S(i).Coms(2,:)*MW^0.5*pi^-1*Ti^-0.5*C.S(i).Speed^-X(3);          %Power coefficient
figure(1)
plot(S(i).flowc,S(i).pressc,'linewid',1.5,'color',color(i,:))
figure(2)
plot(S(i).flowc,S(i).powc,'linewid',1.5,'color',color(i,:))
end

%Curve fitting for pressure coefficient  
if Com==3
Z1=[S(1).flowc(64:end),S(2).flowc,S(3).flowc,S(4).flowc;S(1).pressc(64:end),S(2).pressc,S(3).pressc,S(4).pressc];
Z1s=(sortrows(Z1',1))';
I= find(Z1s(1,:)>0.87,1); 
else
Z1=[S(1).flowc,S(2).flowc,S(3).flowc,S(4).flowc;S(1).pressc,S(2).pressc,S(3).pressc,S(4).pressc];
Z1s=(sortrows(Z1',1))';
I= find(Z1s(1,:)>2,1); 
end


[P,Sa]=polyfit(Z1s(1,1:I),Z1s(2,1:I),3);
Pr=polyval(P,Z1s(1,:));

if 1
    for j=[1:size(Pr,2)]
        m=Z1s(1,j);
        if  (Ca6)>m;
            Pr2(j)=Pr(j);
        else
            Pr2(j)=Pr(j)-(Ca5*(m-Ca6))^Ca7;
        end
    end
end
figure(1)
plot(Z1s(1,:),Pr,'g','linewid',2);
plot(Z1s(1,:),Pr2,'b','linewid',2);

%Curve fitting for power coefficient 
Z2=[S(1).flowc,S(2).flowc,S(3).flowc,S(4).flowc;S(1).powc,S(2).powc,S(3).powc,S(4).powc];
Z2s=(sortrows(Z2',1))';
[Ppow,Spow]=polyfit(Z2s(1,:),Z2s(2,:),5);
Powerf=polyval(Ppow,Z2s(1,:));
figure(2)
plot(Z2s(1,:),Powerf,'linewid',2)









