%Polynomial + nonlinear term approximation of the power consumption.

clc
comcharC2

%Compressor C2
C2.S(1).Power  =[MPoC209;PoC209];
C2.S(2).Power  =[MPoC2095;PoC2095];
C2.S(3).Power  =[MPoC21;PoC21];
C2.S(4).Power  =[MPoC2105;PoC2105];

clearvars -regexp ^*$ -except C2 rho S
close all

figure(1)
hold on
xlabel('Mass flow [Kg/s]'), ylabel('Power at compressor coupling [W]')
grid

% Linear interpolation of the power consumption 
for i=[1:4]
    m=[C2.S(i).Power(1,1):0.1:C2.S(i).Power(1,end)];
    Power  =interp1(C2.S(i).Power(1,:),C2.S(i).Power(2,:),m,'linear');
    C2.S(i).Coms=[m;Power];
    plot(m,Power,'linewid',2)
    plot(C2.S(i).Power(1,:),C2.S(i).Power(2,:),'x','linewid',2)
end

%Polynomial curve fitting with constant speed 
max1=find(C2.S(1).Coms(1,:)>48,1,'first');
max2=find(C2.S(2).Coms(1,:)>53,1,'first');
max3=find(C2.S(3).Coms(1,:)>58,1,'first');
max4=find(C2.S(4).Coms(1,:)>62,1,'first');
Change=[max1, max2, max3, max4];

for i=[1:4]
    ci(i,:) = polyfit(C2.S(i).Coms(1,1:Change(i)),C2.S(i).Coms(2,1:Change(i)),1);
    m=[C2.S(i).Coms(1,1):0.1:C2.S(i).Coms(1,Change(i))+10];
    Powl     =  Polyval(ci(i,:),m);
    C2.S(i).Comcs = [Powl;m];
    plot(C2.S(i).Comcs(2,:),C2.S(i).Comcs(1,:),'k','linewid',2);
    plot(C2.S(i).Coms(1,Change(i)),C2.S(i).Coms(2,Change(i)),'go','linewid',2)
end

%Multidimensional unconstrained nonlinear minimizatio
x1=[53 ,57 ,62 ,67];
x2=[-0.5e-3 ,-0.4e-3 ,-0.5e-3 ,-0.5e-3];
x3=[5, 5, 5 ,5];
   
for i=1:4
    ComcharC2=zeros(3,size(C2.S(i).Coms(1,:),2));
    ComcharC2(1,:)=C2.S(i).Coms(2,:);
    ComcharC2(2,:)=C2.S(i).Coms(1,:);
    ComcharC2(3,[1:2])=[ci(i,1),ci(i,2)];

    x(i,:)=[x1(i),x2(i),x3(i)];
    x0=x(i,:);
    options = optimset('MaxFunEvals',1e15);
    x(i,:)=fminsearch(@(x) objf13(x,ComcharC2),x0,'options'); 
end   

for j=[1:4]
    for i=[1:size(C2.S(j).Coms(1,:),2)]
        m=C2.S(j).Coms(1,i);
        if x(j,1)>m
            P(j,i)=ci(j,1)*m+ci(j,2);
        else
            P(j,i)=ci(j,1)*m+ci(j,2)+x(j,2)*(m-x(j,1))^x(j,3);
        end

    end
    %plot(C2.S(j).Coms(3,:),C2.S(j).Coms(1,:),'--k','linewid',2);
    plot(C2.S(j).Coms(1,:),P(j,:),'--r','linewid',2);
end

figure(2)
hold on
xlabel('Mass flow [Kg/s]'), ylabel('Power at compressor coupling [W]')
axis([30,75,0.6e7,1.8e7])
grid

for i=1:4
    plot(C2.S(i).Coms(1,:),C2.S(i).Coms(2,:),'k','linewid',2);
end

Speedm=[0.85:0.01:1.1];
Speed=[0.9 0.95 1 1.05];
for j=1:size(Speedm,2)
    Speed2=Speedm(j);
    for i=[1:2]
        c(i)=interp1(Speed,ci(:,i)',Speed2,'linear','extrap');
    end
    for i=[1:3]
        c(2+i)=interp1(Speed,x(:,i)',Speed2,'linear','extrap');
    end

    m2=[30:0.1:75];

    for i=[1:size(m2,2)]
            m=m2(i);
            if c(3)>m
                Power2as(i)=c(1)*m+c(2);
            else
                Power2as(i)=c(1)*m+c(2)+c(4)*(m-c(3))^c(5);
            end
    end
    plot(m2,Power2as,'b');    
end







