%Polynomial + nonlinear term approximation of the pressure ratio.

clc
comcharC2

%Compressor C2
C2.S(1).Com    =[MPrC209;RaC209;];
C2.S(1).Power  =[MPoC209;PoC209];

C2.S(2).Com    =[MPrC2095;RaC2095;];
C2.S(2).Power  =[MPoC2095;PoC2095];

C2.S(3).Com    =[MPrC21;RaC21;];
C2.S(3).Power  =[MPoC21;PoC21];

C2.S(4).Com    =[MPrC2105;RaC2105;];
C2.S(4).Power  =[MPoC2105;PoC2105];

Speed=[0.9,0.95,1,1.05];


clearvars -regexp ^*$ -except C2 rho Speed
close all

% Shape-preserving piecewise cubic interpolation of compressor chrateristics 
for i=[1:4]
    minx=min([C2.S(i).Power(1,1),C2.S(i).Com(1,1)]);
    maxx=max([C2.S(i).Power(1,end),C2.S(i).Com(1,end)]);
    X=[minx:0.1:maxx];
    Pratio =interp1(C2.S(i).Com(1,:),C2.S(i).Com(2,:),X,'pchip');
    Power  =interp1(C2.S(i).Power(1,:),C2.S(i).Power(2,:),X,'pchip');
    C2.S(i).Coms=[Pratio;Power;X];
end

%Polynomial curve fitting with constant speed 
a1=100;
a2=100;
Change=[nearest(a2*0.9), nearest(a2*0.95), nearest(a2*1), nearest(a2*1.05)]+a1;

for i=[1:4]
    Pcs(i,:) = polyfit(C2.S(i).Coms(3,1:Change(i)),C2.S(i).Coms(1,1:Change(i)),3);
    Prcs     =  Polyval(Pcs(i,:),[C2.S(i).Coms(3,1):0.1:C2.S(i).Coms(3,end)+3]);
    Power=zeros(size(Prcs));% ikke lagt til enda 
    C2.S(i).Comcs = [Prcs;Power;[C2.S(i).Coms(3,1):0.1:C2.S(i).Coms(3,end)+3]];
end

%Multidimensional unconstrained nonlinear minimizatio
x1=[53 ,57 ,62 ,67];
x2=[-0.5e-3 ,-0.4e-3 ,-0.5e-3 ,-0.5e-3];
x3=[5, 5, 5 ,5];
   
for i=1:4
    ComcharC2=zeros(3,size(C2.S(i).Coms(3,:),2));
    ComcharC2(1,:)=C2.S(i).Coms(1,:);
    ComcharC2(2,:)=C2.S(i).Coms(3,:);
    ComcharC2(3,[1:4])=[Pcs(i,1),Pcs(i,2),Pcs(i,3),Pcs(i,4)];

    x(i,:)=[x1(i),x2(i),x3(i)];
    x0=x(i,:);
    options = optimset('MaxFunEvals',1e15);
    x(i,:)=fminsearch(@(x) objf9(x,ComcharC2),x0,'options'); 
end

%Plots 
if 1
    for i=[1:1]
    figure(i)
    hold on 
    grid
    end
    for i=[1:4]
        figure(1)
        plot(C2.S(i).Coms(3,:),C2.S(i).Coms(1,:),'--k','linewid',2)
        plot(C2.S(i).Comcs(3,:),C2.S(i).Comcs(1,:),'k','linewid',2);
        plot(C2.S(i).Com(1,:),C2.S(i).Com(2,:),'kx','linewid',2)
        plot(C2.S(i).Coms(3,Change(i)),C2.S(i).Coms(1,Change(i)),'ko','linewid',2)
        f(i)=sum((C2.S(i).Comcs(1,1:Change(i))-C2.S(i).Coms(1,1:Change(i))).^2);
    end
    ftot=sum(f)
end

if 2
    figure(2)
    hold on 
    grid
    for j=[1:4]
        Prsp=C2.S(j).Coms(1,:);
        for i=[1:size(Prsp,2)]
            m=C2.S(j).Coms(3,i);
            if x(j,1)>m
                Pr(j,i)=Pcs(j,1)*m^3+Pcs(j,2)*m^2+Pcs(j,3)*m+Pcs(j,4);
            else
                Pr(j,i)=Pcs(j,1)*m^3+Pcs(j,2)*m^2+Pcs(j,3)*m+Pcs(j,4)+x(j,2)*(m-x(j,1))^x(j,3);
            end

        end
        f(j)=sum((Prsp-Pr(j,:)).^2);
        plot(C2.S(j).Coms(3,:),C2.S(j).Coms(1,:),'--k','linewid',2);
        %plot(C2.S(j).Coms(3,:),Pr(j,:),'linewid',2);
    end
end

Speedm=[0.85:0.01:1.1];
for j=1:size(Speedm,2)
    Speed2=Speedm(j);
    for i=[1:4]
        c(i)=interp1(Speed,Pcs(:,i)',Speed2,'linear','extrap');
    end
    for i=[1:3]
        c(4+i)=interp1(Speed,x(:,i)',Speed2,'linear','extrap');
    end

    m2=[30:0.1:75];

    for i=[1:size(m2,2)]
            m=m2(i);
            if c(5)>m
                Pr2(i)=c(1)*m^3+c(2)*m^2+c(3)*m+c(4);
            else
                Pr2(i)=c(1)*m^3+c(2)*m^2+c(3)*m+c(4)+c(6)*(m-c(5))^c(7);
            end
    end
    plot(m2,Pr2,'b');
end

axis([30,75,1.5,6]);
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')









