%Polynomial + nonlinear term approximation of the pressure ratio.

clc
comcharC3

%Compressor C2
C2.S(1).Com    =[MPrC309;RaC309;];
C2.S(2).Com    =[MPrC3095;RaC3095;];
C2.S(3).Com    =[MPrC31;RaC31;];
C2.S(4).Com    =[MPrC3105;RaC3105;];

Speed=[0.9,0.95,1,1.05];

clearvars -regexp ^*$ -except C2 rho Speed
close all

figure(1)
hold on
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')
grid



% Shape-preserving piecewise cubic interpolation of compressor chrateristics 
for i=[1:4]
    m=[C2.S(i).Com(1,1):0.1:C2.S(i).Com(1,end)+0.1];
    Pratio =interp1(C2.S(i).Com(1,:),C2.S(i).Com(2,:),m,'pchip');
    C2.S(i).Coms=[m;Pratio];
    plot(C2.S(i).Coms(1,:), C2.S(i).Coms(2,:));
    plot(C2.S(i).Com(1,:), C2.S(i).Com(2,:),'kx');
end

%Polynomial curve fitting with constant speed 
max1=find(C2.S(1).Coms(1,:)>8.2,1,'first');
max2=find(C2.S(2).Coms(1,:)>9,1,'first');
max3=find(C2.S(3).Coms(1,:)>9.8,1,'first');
max4=find(C2.S(4).Coms(1,:)>10.3,1,'first');
Change=[max1, max2, max3, max4];

for i=[1:4]
    Pcs(i,:) = polyfit(C2.S(i).Coms(1,1:Change(i)),C2.S(i).Coms(2,1:Change(i)),3);
    m=[C2.S(i).Coms(1,1):0.1:C2.S(i).Coms(1,Change(i))+1];
    Powl     =  Polyval(Pcs(i,:),m);
    C2.S(i).Comcs = [Powl;m];
    plot(C2.S(i).Comcs(2,:),C2.S(i).Comcs(1,:),'k','linewid',2);
    plot(C2.S(i).Coms(1,Change(i)),C2.S(i).Coms(2,Change(i)),'go','linewid',2)
end


%Multidimensional unconstrained nonlinear minimizatio
x1=[8.2 ,9 ,9.8 ,10.2];
x2=[-0.5e-3 ,-0.4e-3 ,-0.5e-3 ,-0.5e-3];
x3=[5, 5, 5 ,5];
   
for i=1:4
    ComcharC2=zeros(3,size(C2.S(i).Coms(1,:),2));
    ComcharC2(1,:)=C2.S(i).Coms(2,:);
    ComcharC2(2,:)=C2.S(i).Coms(1,:);
    ComcharC2(3,[1:4])=[Pcs(i,1),Pcs(i,2),Pcs(i,3),Pcs(i,4)];
    x(i,:)=[x1(i),x2(i),x3(i)];
    x0=x(i,:);
    options = optimset('MaxFunEvals',1e15);
    x(i,:)=fminsearch(@(x) objf9(x,ComcharC2),x0,'options');
end

figure(2)
hold on 
grid
    for j=[1:4]
        mtot=C2.S(j).Coms(1,:)
        for i=1:size(mtot,2)
            m=mtot(i);
            if x(j,1)>m
                Pr(i)=Pcs(j,1)*m^3+Pcs(j,2)*m^2+Pcs(j,3)*m+Pcs(j,4);
            else
                Pr(i)=Pcs(j,1)*m^3+Pcs(j,2)*m^2+Pcs(j,3)*m+Pcs(j,4)+x(j,2)*(m-x(j,1))^x(j,3);
            end
           
        end
        plot(C2.S(j).Coms(1,:),C2.S(j).Coms(2,:),'--k','linewid',2);
        plot(mtot,Pr,'linewid',2);
        plot(C2.S(j).Com(1,:), C2.S(j).Com(2,:),'rx');
        clearvars Pr
    end

%Manual adjustment of the unknown parameters       
x=  [6.9521   -0.0004    9.9733;
    7.7634   -0.0006   10.5329;
    8.4741   -0.0016    9.9904;
    9.1519   -0.0012   10.503];
    
    
Speedm=[0.85:0.01:1.1];
for j=1:size(Speedm,2)
    Speed2=Speedm(j);
    for i=[1:4]
        c(i)=interp1(Speed,Pcs(:,i)',Speed2,'linear','extrap');
    end
    for i=[1:3]
        c(4+i)=interp1(Speed,x(:,i)',Speed2,'linear','extrap');
    end

    m2=[5:0.1:12];

    for i=[1:size(m2,2)]
            m=m2(i);
            if c(5)>m
                Pr2(i)=c(1)*m^3+c(2)*m^2+c(3)*m+c(4);
            else
                Pr2(i)=c(1)*m^3+c(2)*m^2+c(3)*m+c(4)+c(6)*(m-c(5))^c(7);
            end
    end
    plot(m2,Pr2,'b');
end

axis([5,12,1.5,5]);
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')









