%Polynomial + nonlinear term approximation of the power consumption.

clc
comcharC3

%Compressor C2
C2.S(1).Power  =[MPoC309;PoC309];
C2.S(2).Power  =[MPoC3095;PoC3095];
C2.S(3).Power  =[MPoC31;PoC31];
C2.S(4).Power  =[MPoC3105;PoC3105];

clearvars -regexp ^*$ -except C2 rho S
close all

figure(1)
hold on
xlabel('Mass flow [Kg/s]'), ylabel('Power at compressor coupling [W]')
grid

% Linear interpolation of the power consumption 
for i=[1:4]
    m=[C2.S(i).Power(1,1):0.1:C2.S(i).Power(1,end)+0.1];
    Power  =interp1(C2.S(i).Power(1,:),C2.S(i).Power(2,:),m,'linear','extrap');
    C2.S(i).Coms=[m;Power];
    plot(m,Power,'linewid',2)
    plot(C2.S(i).Power(1,:),C2.S(i).Power(2,:),'x','linewid',2)
end

%Polynomial curve fitting with constant speed 
max1=find(C2.S(1).Coms(1,:)>8.2,1,'first');
max2=find(C2.S(2).Coms(1,:)>8.6,1,'first');
max3=find(C2.S(3).Coms(1,:)>9.3,1,'first');
max4=find(C2.S(4).Coms(1,:)>10.2,1,'first');
Change=[max1, max2, max3, max4];

for i=[1:4]
    ci(i,:) = polyfit(C2.S(i).Coms(1,1:Change(i)),C2.S(i).Coms(2,1:Change(i)),1);
    m=[C2.S(i).Coms(1,1):0.1:C2.S(i).Coms(1,Change(i))+1];
    Powl     =  Polyval(ci(i,:),m);
    C2.S(i).Comcs = [Powl;m];
    plot(C2.S(i).Comcs(2,:),C2.S(i).Comcs(1,:),'k','linewid',2);
    plot(C2.S(i).Coms(1,Change(i)),C2.S(i).Coms(2,Change(i)),'go','linewid',2)
end

%Multidimensional unconstrained nonlinear minimizatio
x1=[8.2 ,8.6 ,9.3 ,10.2];
x2=[-0.5e-3 ,-0.4e-3 ,-0.5e-3 ,-0.5e-3];
x3=[5, 5, 5 ,5];
   
for i=1:4
    ComcharC2=zeros(3,size(C2.S(i).Coms(1,:),2));
    ComcharC2(1,:)=C2.S(i).Coms(2,:);
    ComcharC2(2,:)=C2.S(i).Coms(1,:);
    ComcharC2(3,[1:2])=[ci(i,1),ci(i,2)];

    x(i,:)=[x1(i),x2(i),x3(i)];
    x0=x(i,:);
    options = optimset('MaxFunEvals',1e15);
    x(i,:)=fminsearch(@(x) objf13(x,ComcharC2),x0,'options'); 
end   

for j=[1:4]
    for i=[1:size(C2.S(j).Coms(1,:),2)]
        m=C2.S(j).Coms(1,i);
        if x(j,1)>m
            P(j,i)=ci(j,1)*m+ci(j,2);
        else
            P(j,i)=ci(j,1)*m+ci(j,2)+x(j,2)*(m-x(j,1))^x(j,3);
        end

    end
    %plot(C2.S(j).Coms(3,:),C2.S(j).Coms(1,:),'--k','linewid',2);
    plot(C2.S(j).Coms(1,:),P(j,[1:i]),'--r','linewid',2);
end

%Manual adjustment of the unknown parameters   

x= [  5.2873e+000 -1.6817e-005  1.6514e+001
      4.5863e+000 -2.3766e-005  1.3466e+001;
      5.6094e+000 -1.0189e-004  1.3279e+001;
      6.8830e+000 -6.5688e-004  1.3571e+001;]


figure(2)
hold on
xlabel('Mass flow [Kg/s]'), ylabel('Power at compressor coupling [W]')
axis([5,12,1e6,2.2e6])
grid

for i=1:4
    plot(C2.S(i).Coms(1,:),C2.S(i).Coms(2,:),'k','linewid',2);
end

Speedm=[0.85:0.01:1.1];
Speed=[0.9 0.95 1 1.05];
for j=1:size(Speedm,2)
    Speed2=Speedm(j);
    for i=[1:2]
        c(i)=interp1(Speed,ci(:,i)',Speed2,'linear','extrap');
    end
    for i=[1:3]
        c(2+i)=interp1(Speed,x(:,i)',Speed2,'linear','extrap');
    end

    m2=[5:0.1:12];

    for i=[1:size(m2,2)]
            m=m2(i);
            if c(3)>m
                Power2as(i)=c(1)*m+c(2);
            else
                Power2as(i)=c(1)*m+c(2)+c(4)*(m-c(3))^c(5);
            end
    end
    plot(m2,Power2as,'b');    
end







