% Isentropic efficiency and isentropic head
comcharC2

%Compressor C2
C2.S(1).Com    =[MPrC209;RaC209;];
C2.S(1).Power  =[MPoC209;PoC209];
C2.S(1).Speed  =0.9;

C2.S(2).Com    =[MPrC2095;RaC2095;];
C2.S(2).Power  =[MPoC2095;PoC2095];
C2.S(2).Speed  =0.95;

C2.S(3).Com    =[MPrC21;RaC21;];
C2.S(3).Power  =[MPoC21;PoC21];
C2.S(3).Speed  =1;

C2.S(4).Com    =[MPrC2105;RaC2105;];
C2.S(4).Power  =[MPoC2105;PoC2105];
C2.S(4).Speed  =1.05;

clearvars -regexp ^*$ -except C2 rho
close all

%Interpolation between points in compressor characteristics 
for i=[1:4]
    minx=min([C2.S(i).Power(1,1),C2.S(i).Com(1,1)]);
    maxx=max([C2.S(i).Power(1,end),C2.S(i).Com(1,end)]);
    massflow=[minx:0.1:maxx];
    Pratio =interp1(C2.S(i).Com(1,:),C2.S(i).Com(2,:),massflow,'pchip');
    Power  =interp1(C2.S(i).Power(1,:),C2.S(i).Power(2,:),massflow,'lin');
    C2.S(i).Coms=[Pratio;Power;massflow];
end

%Inlet conditions 
Pin=34.25*10^5;     %Pressure [Pa]
Tin=29.25+273.15;   %Temperature [K]
MW=23.12;           %Molecular weight [g/mol]
Kin=1.203;          %Specific heats
Zin=0.877;          %Compressibility
Vin=4455;            %Volume Flow (m^3/h)

%Disharge conditions 
Pout=152*10^5;      %Pressure [Pa]
Tout=194+273.15;    %Temperature [K]
Kout=1.361;         %Specific heats
Zout=0.929;         %Compressibility

R=8314;             %The universal gas constant
Pohed=182*10^3;     %Polytropic Head [j/kg]
Poeff=74.2;         %Polytropic Efficienct (%)
Power=10.690*10^6;  %Reguierd Power [W]
Rw=R/MW;            %Characteristic gas constant

%Average conditions 
Zavg=(Zin+Zout)/2;
Kavg=(Kin+Kout)/2;

%Isentropic head and efficiency in operation case 1
rho=Pin*MW/(Zin*R*Tin);   %Density [kg/m^3]
Min=Vin*rho/3600;         %Mass flow [Kg/s]
Ws1=(Kavg/(Kavg-1))*Zavg*Rw*Tin*((Pout/Pin)^((Kavg-1)/Kavg)-1); %Isentropic head [j/kg]
Etas1=Min*Ws1/Power; %Isentropic efficiency

%Isothermal head
Wit=Zavg*Rw*Tin*log(Pin/Pout);

figure(1)
subplot(2,1,2)
hold on
grid
xlabel('Mass flow [Kg/s]'), ylabel('Isentropic efficiency [%]')
axis([30,75,0.4,0.8])
subplot(2,1,1)
hold on
grid
xlabel('Mass flow [Kg/s]'), ylabel('Pressure ratio')
axis([30,75,1,6])
figure(2)
hold on
grid

%Isentropic head and efficiency

L(1).type=['k-']; L(2).type=['k--']; L(3).type=['k-']; L(4).type=['k--'];

for i=[1:4]
    Pra=C2.S(i).Coms(1,:);  %Pressure ratio
    Pow=C2.S(i).Coms(2,:);  %Power
    M=C2.S(i).Coms(3,:);    %Mass flow
    Ws=(Kavg/(Kavg-1))*Zavg*Rw*Tin*((Pra).^((Kavg-1)/Kavg)-1);   %Isentropic head [j/kg]
    Etas=M.*Ws./Pow;                                             %Isentropic efficiency
    C2.S(i).Isen=[Ws;Etas;M];
    figure(1)
    subplot(2,1,1)
    plot(C2.S(i).Coms(3,:), C2.S(i).Coms(1,:),L(i).type,'linewid',2)
    subplot(2,1,2)
    plot(M,Etas,L(i).type,'linewid',2)
    figure(2)
    plot(C2.S(i).Coms(3,:), C2.S(i).Coms(2,:),'k','linewid',2)
end

figure(1)
subplot(2,1,1)
text(55.5,1.5,'0.9','FontSize',12,'FontWeight','bold')
text(61,1.8,'0.95','FontSize',12,'FontWeight','bold')
text(66.5,2.2,'1','FontSize',12,'FontWeight','bold')
text(70,2.3,'1.05','FontSize',12,'FontWeight','bold')

subplot(2,1,2)
text(55.5,0.43,'0.9','FontSize',12,'FontWeight','bold')
text(61,0.45,'0.95','FontSize',12,'FontWeight','bold')
text(66.5,0.5,'1','FontSize',12,'FontWeight','bold')
text(70,0.47,'1.05','FontSize',12,'FontWeight','bold')







