close all
clear
clc
tic
%Critical Pressure, critical temperature and acentric factor
%From Chemical Properties Handbook
%     Nitrogen Methane, Ethane,  Propane,i-Butane,n-Butane,i-pentane,n-pentane,n-hexane, c7+
Tc = [126.1    190.58   305.42   369.82  408.14   425.18   460.43    469.65    507.43    720.6];        %Kelvin   
Pc = [33.94    46.04    48.8     42.49   36.48    37.97    33.81     33.69     30.12     14.19]*10^5;   %Pa
w  = [0.040    0.011    0.099    0.152   0.177    0.199    0.228     0.249     0.305     0.747];        %Undimensional
MW  =[28.013   16.043   30.070   44.096  58.123   58.123   72.150    72.150    86.177    295  ];        %gram per mole    

%Feed composition
zf(1,:) = [2.071 59.58 11.40 7.984 0.784 2.193 0.358 0.412 0.218 15]; %Fluid 1
zf(2,:) = [1.706 49.06 9.390 6.577 0.646 1.806 0.295 0.340 0.180 30]; %Fluid 2
zf(3,:) = [1.341 38.55 7.377 5.167 0.507 1.419 0.232 0.266 0.141 45]; %Fluid 3  
Fm=[11960 6010 4020]
nc   = 10;
   
%Binary interaction parameter (If there are)
kij=zeros(11,11);



P1=[2:0.5:45]*10^5;
T1=70+273.15;
P2=1*10^5;
T2=66.11+273.15;

Imat=zeros(size(P1,2),size(P2,2));

for j=1:3
    z=zf(j,:)
    z=z/sum(z);
    for i=1:size(P1,2)
        %Call for Isothermal flash calculations
        Flowin=Fm(j);%2791; %[Kg mol/h]
        %Separtor 1
        [x1,y1,beta1,K1]=flashcalc(T1,P1(i),z,Tc,Pc,w,kij);  
        Flow1=Flowin*(1-beta1);
        %Separator 2
        [x2,y2,beta2,K2]=flashcalc(T2,P2,x1,Tc,Pc,w,kij);  
        Flow2=Flow1*(1-beta2);
        [API2,rho_oil]=API(x2,Tc,Pc,w,kij,MW,nc);

    Flow4=Flow2*sum(x2.*MW)/3600;           %mass flow [kg/s]
    bps(j,i)=Flow4/(rho_oil*0.1589823);          %barrels per second
    end
end

figure(1)
xlabel('Initial separator pressure [bar]') ,ylabel('Oil recovery [bps]')
hold on
plot(P1*10^-5,bps(1,:),'r','linewid',2)
plot(P1*10^-5,bps(2,:),'k','linewid',2)
plot(P1*10^-5,bps(3,:),'b','linewid',2)
legend('Fluid 1','Fluid 2','Fluid 3')
grid











