function [incom,mvvec,Fvvec,yvec]=Separators(P1,P2,z,Flowin)

%Critical Pressure, critical temperature and acentric factor
%From Chemical Properties Handbook
%     Nitrogen Methane, Ethane,  Propane,i-Butane,n-Butane,i-pentane,n-pentane,n-hexane, c7+
Tc = [126.1    190.58   305.42   369.82  408.14   425.18   460.43    469.65    507.43    720.6];        %Kelvin   
Pc = [33.94    46.04    48.8     42.49   36.48    37.97    33.81     33.69     30.12     14.19]*10^5;   %Pa
w  = [0.040    0.011    0.099    0.152   0.177    0.199    0.228     0.249     0.305     0.747];        %Undimensional
MW  =[28.013   16.043   30.070   44.096  58.123   58.123   72.150    72.150    86.177    295  ];        %gram per mole    

z=z/sum(z);
nc   = 10;
   
%Binary interaction parameter (If there are)
kij=zeros(11,11);

%Call for Isothermal flash calculations
%Separtor 1
T1=70+273.15;
[x1,y1,beta1,K1]=flashcalc(T1,P1,z,Tc,Pc,w,kij);  
Fl1=Flowin*(1-beta1);
Fv1=Flowin*beta1;
mv1=Fv1*sum(y1.*MW)/3600; 

%Separator 2
T2=68.71+273.15;
[x2,y2,beta2,K2]=flashcalc(T2,P2,x1,Tc,Pc,w,kij);  
Fl2=Fl1*(1-beta2);
Fv2=Fl1*beta2;
mv2=Fv2*sum(y2.*MW)/3600; 

%Separator 3
P3=2*10^5;
T3=66.11+273.15;
[x3,y3,beta3,K3]=flashcalc(T3,P3,x2,Tc,Pc,w,kij);  
Fl3=Fl2*(1-beta3);
Fv3=Fl2*beta3;
mv3=Fv3*sum(y3.*MW)/3600; 
%API
[API2,rho_oil]=API(x3,Tc,Pc,w,kij,MW);

ml3=Fl3*sum(x3.*MW)/3600;             %mass flow [kg/s]
bps=ml3/(rho_oil*0.1589823);          %barrels per second

xapi=  [50 45 40 30];
yprice=[49.625 50 50 48.5];

Price_oil=interp1(xapi,yprice,API2,'linear','extrap');
incom=Price_oil*bps;

mvvec=[mv1,mv2,mv3];
Fvvec=[Fv1,Fv2,Fv3];
yvec=[y1;y2;y3];

end