function [Expenses,U1,U2,PoutC2,PrC2,PrC3,nonco]=compressors(P1,P2,Nc,PrC4,mvvec,Fvvec,yvec)

%Critical Pressure, critical temperature and acentric factor
%From Chemical Properties Handbook
%     Nitrogen Methane, Ethane,  Propane,i-Butane,n-Butane,i-pentane,n-pentane,n-hexane, c7+
MW  =[28.013   16.043   30.070   44.096  58.123   58.123   72.150    72.150    86.177    295  ];        %gram per mole    

P3=2*10^5;
mv1=mvvec(1); mv2=mvvec(2); mv3=mvvec(3);
Fv1=Fvvec(1); Fv2=Fvvec(2); Fv3=Fvvec(3);
y1=yvec(1,:);  y2=yvec(2,:);    y3=yvec(3,:);

%Compressor C4
[PowerC4,nonco,mrcC4]=sscompressorC4(PrC4,mv3);
PoutC4=PrC4*P3;

%Compressor C3 
PinC3=PoutC4;
mC3=mv2+mv3;
yC3=(Fv2/(Fv2+Fv3)).*y2+(Fv3/(Fv2+Fv3)).*y3;
MWC3=sum(yC3.*MW);
TiC3=29.1+273.15;      %Inlet temprature [k];
[PoutC3,PowerC3]=sscomdim2(mC3,Nc,PinC3,TiC3,MWC3,3);
PrC3=PoutC3/PinC3;

%Compressor C2 
PinC2=PoutC3;
mC2=mv1+mv2+mv3;
yC2=(Fv1/(Fv1+Fv2+Fv3)).*y1+(Fv2/(Fv1+Fv2+Fv3)).*y2+(Fv3/(Fv1+Fv2+Fv3)).*y3;
MWC2=sum(yC2.*MW);
TiC2=29.8+273.15;      %Inlet temprature [k];
[PoutC2,PowerC2]=sscomdim2(mC2,Nc,PinC2,TiC2,MWC2,2);
PrC2=PoutC2/PinC2;

%Separator S1 gas valve opening  
Vc1=0.25;             %Valve constant
if P1>PinC2
    U1=mv1/(Vc1*(P1-PinC2)^0.5);
else
    U1=-mv1/(Vc1*(PinC2-P1)^0.5);
end

%Separator S2 gas valve opening  
Vc2=0.03;              %Valve constant
if P2>PinC3
    U2=mv2/(Vc2*(P2-PinC3)^0.5);
else
    U2=-mv2/(Vc2*(PinC3-P2)^0.5);
end

Powertot=PowerC2+PowerC3+PowerC4;
Price_el=2.13e-8;   %Electricity price [$/Ws]
Expenses=Powertot*Price_el;
end