%Steady state compressor model for compressor C4  
%[Power,nonco,mrv]=sscompressorC4(Pr,min)
%Input parameters
    %Pr:     Pressure ratio 
    %min:    Mass flow      [Kg/s]
%
%Output parameters
    %Power:  Power consumption                 [W]
    %noncon: The operation point is feasible if nonco<=0 
    %mrc:    Mass flow through recycel vale    [Kg/s]

function [Power,nonco,mrv]=sscompressorC4(Pr,min)

%Surge control line
C1=2.5;
C2=0;
Prsurge=C1*min+C2;

if Pr>Prsurge;
    m=(Pr-C2)/C1;
    mrv=m-min;
else
    m=min;
    mrv=0;
end

%Feasible operation point 
Prmaxvec=[14.3400 14.3400 14.0769 13.3077 11.8462 10.6154 8.0769 5.6154];
mmaxvec= [0       5.7370  5.9076  6.1538  6.3999  6.5230  6.6461 6.6768];
Prmax=interp1(mmaxvec,Prmaxvec,m,'linear','extrap');
nonco=Pr-Prmax;

%Power consumption 
Cpower=[2.013485899063293e+005 2.710847694636494e+004 -7.840711647288843e+004];
Power=Cpower(1)*m+Cpower(2)*Pr+Cpower(3);
end