% Fugacity coeficient calculation using Peng Robinson equation of state

function [Phi,Z]=Phi(P,T,xy,Tc,Pc,w,kij,R,nc,phase)

%Reduced pressure and temperature 
Pr=P./Pc;
Tr=T./Tc;

a=0.45724*(R*Tc).^2./Pc;
b=0.07780*R*Tc./Pc;

n=zeros(1,nc);
for i=1:nc
    if w(i) <= 0.491
        n(i)=0.37464+1.54226*w(i)-0.26992*w(i)^2;
    else
        n(i)=0.379642+1.48503*w(i)-0.164423*w(i)^2+0.016666*w(i)^3;
    end
end

alfa=(1+n.*(1-Tr.^0.5)).^2;
Ai=0.45724*alfa.*Pr./Tr.^2;
Bi=0.07780*Pr./Tr;

A=0;
B=0;
aalfa=0;
for i=1:nc
    for j=1:nc
        A=xy(i)*xy(j)*(1-kij(i,j))*(Ai(i)*Ai(j))^0.5+A;
        aalfa=xy(i)*xy(j)*(1-kij(i,j))*(a(i)*alfa(i)*a(j)*alfa(j))^0.5+aalfa;
    end
    B=xy(i)*Bi(i)+B;
end

switch phase    
    case ('vapor')
        Z = max(roots([1 -(1-B) (A-3*B^2-2*B) -(A*B-B^2-B^3)]));
    case ('liquid')
        Z = min(roots([1 -(1-B) (A-3*B^2-2*B) -(A*B-B^2-B^3)]));
end

for i=1:nc
    h1=0;
    for j=1:nc
        h1=xy(j)*(1-kij(i,j))*(a(i)*alfa(i)*a(j)*alfa(j))^0.5+h1;
    end
    Phi(i)=Bi(i)/B*(Z-1)-log(Z-B)+A/(2.828*B)*(Bi(i)/B-2/aalfa*h1)*log((Z+2.414*B)/(Z-0.414*B));
end
Phi = exp(Phi);
end

    
