% Isothermal flash calculation using Peng Robinson equation of state

function [x,y,beta,K]=flashcalc(T,P,z,Tc,Pc,w,kij) 



%Ideal gas universal constant 
R=8314.472; %[J/(mol)]

%Number of component in feed. 
nc   = size(z,2);

%Feed composition normalization
z=z/sum(z);

%Initial values for the phase equilibria constant
K=Pc./P.*exp(5.37*(1+w).*(1-Tc./T));
epsilon1=1;

while epsilon1 > 1e-14
    beta_old=1;
    epsilon=1;
    while epsilon >=1.e-14
        %Rachford Rice
        beta_new=beta_old+sum((z.*(K-1))./(1+beta_old*(K-1)))./sum((z.*(K-1).^2)./((1+beta_old*(K-1)).^2));
        %Check that beta_new is between 0.001 and 0.99 
        if beta_new >=0.999
            beta_new=0.999;
        elseif beta_new <=0.001
            beta_new=0.001;
        end
        %Check convergenc 
        epsilon=abs(beta_new-beta_old);
        %Update beta
        beta_old=beta_new;
    end
    beta=beta_new;
    
    %Vapor Phase Composition
    y=z.*K./(1+beta*(K-1));
    %Liquid Phase Composition:
    x=z./(1+beta*(K-1));

    %Normalise
    for i=1:nc; 
        if (x(i)<0.0); x(i) = 1.0e-07; end;	
        if (y(i)<0.0); y(i) = 1.0e-07; end;	
    end
    x=x/sum(x);		y=y/sum(y);	

    %Vapor fugacity coeficcient 
    [phiv,Zvap] = Phi(P,T,y,Tc,Pc,w,kij,R,nc,'vapor');
    %Liquid fugacity coeficcient 
    [phil,Zliq] = Phi(P,T,x,Tc,Pc,w,kij,R,nc,'liquid');

    Fv  = y.*phiv*P;
    Fl  = x.*phil*P;
    K  = K.*(Fl./Fv);
    epsilon1 = sum((Fl./Fv-1).^2); %convergence 
end
